#!/usr/bin/env python

from setuptools import setup, find_packages, Extension
from distutils.command.bdist_rpm import bdist_rpm as _bdist_rpm

_bdist_rpm.user_options.append(('autoreq=', None, "Add autoreq flag to spec."))
class bdist_rpm(_bdist_rpm):

   def __init__(self, *args, **kw):
       self.autoreq = None
       _bdist_rpm.__init__(self, *args, **kw)

   def finalize_package_data(self):
       self.ensure_string("autoreq", "1")
       _bdist_rpm.finalize_package_data(self)

   def _make_spec_file(self):
      output = _bdist_rpm._make_spec_file(self)
      if getattr(self, 'autoreq', "1") == "1":
          return output
      else:
          return output[:5] + ['Autoreq: 0'] + output[5:]

ext_modules= []

setup(cmdclass={'bdist_rpm': bdist_rpm,},
    name="gridpp-dpm-tools",
    version="2.6.4",
    author="Greig Cowan, Sam Skipsey, Wahid Bhimji",
    author_email="sskipsey@googlemail.com",
    url="http://www.gridpp.ac.uk/wiki/DPM-admin-tools",
    description="GridPP DPM administration toolkit",
    package_dir={'gridpp-dpm-tools':'src/gridpp-dpm-tools'},
    packages=find_packages("src"),
    include_package_data=True,
    zip_safe = False,
    licence = 'GPLv2+',

    ext_modules=ext_modules,

    classifiers = [
        'Development Status :: 3 - Beta',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Natural Language :: English',
        'Operating System :: POSIX'
    ],

    install_requires=["DPM-interfaces","MySQL-python"],

    data_files=[('/opt/lcg/bin/', ['src/dpm-disk-to-dpns',
			      	   'src/dpm-dpns-to-disk',
			           'src/dpns-du',
			      	   'src/dpns-find',
			      	   'src/dpm-list-disk',
			   	   'src/dpm-sql-spacetoken-list-files',
				   'src/dpm-sql-spacetoken-usage',
				   'src/dpm-sql-usage-by-vo-user',
				   'src/dpm-delreplica',
				   'src/dpm-sql-list-hotfiles',
                                   'src/dpm-sql-spacetoken-replicate-hotfiles',
                                   'src/README']),
				('/opt/lcg/etc/', 
				   ['src/accountingdb.sql', 'src/usage_accounting'])
              ],

)
